@@ -17,7 +17,7 @@
  *                                                                            *
  *  You should have received a copy of the GNU General Public License         *
  *  along with this program; if not, write to the Free Software               *
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA *
  *                                                                            *
  *****************************************************************************/
 
@@ -50,18 +50,12 @@ void handle_gui_input(char c) {
             if (iface_list==NULL && show_all_if==1) show_all_if=2;
             /* get stats so all values are uptodate */
             get_iface_stats(0);
-            /* a short sleep, else we get "nan" values due to very short 
-               delay till next get_iface_stats */
-            usleep(100);
             break;
         case 's':
         case 'S':
             sumhidden=!sumhidden;
             /* get stats so all values are uptodate */
             get_iface_stats(0);
-            /* a short sleep, else we get "nan" values due to very short
-               delay till next get_iface_stats */
-            usleep(100);
             break;
         case 'n':
         case 'N':
