@@ -17,7 +17,7 @@
  *                                                                            *
  *  You should have received a copy of the GNU General Public License         *
  *  along with this program; if not, write to the Free Software               *
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA *
  *                                                                            *
  *****************************************************************************/
 
@@ -25,13 +25,13 @@
 #include "output.h"
 
 inline static const char *output_type2str(void);
-inline const char *input2str(void);
-inline const char *show_all_if2str(void);
-inline ullong direction2value(char mode,struct inout_long stats);
+static inline const char *input2str(void);
+static inline const char *show_all_if2str(void);
+static inline ullong direction2value(char mode,struct inout_long stats);
 #if EXTENDED_STATS
-inline double direction_max2value(char mode,struct inouttotal_double stats,int items);
+static inline double direction_max2value(char mode,struct inouttotal_double stats,int items);
 #endif
-inline char *dyn_byte_value2str(double value,char *str,int buf_size);
+static inline char *dyn_byte_value2str(double value,char *str,int buf_size);
 char *values2str(char mode,t_iface_speed_stats stats,t_iface_stats full_stats,float multiplier,char *str,int buf_size);
 
 inline static const char *output_type2str(void) {
@@ -59,7 +59,7 @@ inline static const char *output_type2str(void) {
 }
 
 
-inline const char *input2str(void) {
+static inline const char *input2str(void) {
     switch (input_method) {
 #ifdef SYSCTL
         case SYSCTL_IN:
@@ -121,7 +121,7 @@ inline const char *input2str(void) {
     return "";
 }
 
-inline const char *show_all_if2str(void) {
+static inline const char *show_all_if2str(void) {
     switch (show_all_if) {
         case 1:
 				return " (all)";
@@ -234,6 +234,7 @@ int print_header(int option) {
 	        fprintf(tmp_out_file,"<div class=\"bwm-ng-header\">bwm-ng bwm-ng v" VERSION " (refresh %is); input: ",html_refresh);
             fprintf(tmp_out_file,"%s", input2str());
             fprintf(tmp_out_file,"%s", show_all_if2str());
+            if (output_type==SUM_OUT) fprintf(tmp_out_file,"<br>Started: %s", start_time);
 	        fprintf(tmp_out_file,"</div><table class=\"bwm-ng-output\">");
 			fprintf(tmp_out_file,"<tr class=\"bwm-ng-head\"><td class=\"bwm-ng-name\">Interface</td><td>Rx</td><td>Tx</td><td>Total</td></tr>");
 			break;
@@ -241,10 +242,12 @@ int print_header(int option) {
 		case PLAIN_OUT_ONCE:
 		case PLAIN_OUT:
 			if (output_method==PLAIN_OUT && ansi_output) printf("\033[1;2H");
-	        printf("bwm-ng v" VERSION " (delay %2.3fs); ",(float)delay/1000);
-			if (output_method==PLAIN_OUT) printf("press 'ctrl-c' to end this%s",(ansi_output ? "\033[2;2H" : "")); else printf("input: ");
-            printf("%s", input2str());
-            printf("%s\n",show_all_if2str());
+
+	        printf("bwm-ng v" VERSION " (delay %2.3fs); ", (float)delay/1000);
+			if (output_method==PLAIN_OUT && output_type==SUM_OUT) printf("started: %s; ", start_time);
+            if (output_method==PLAIN_OUT) printf(ansi_output ? "\033[2;2H" : "\n");
+            printf("input: %s%s", input2str(), show_all_if2str());
+            if (output_method==PLAIN_OUT) printf("; press 'ctrl-c' to end this\n");
 			if (output_method==PLAIN_OUT) {
 				if (ansi_output)
 					printf("\033[3;2H");
@@ -262,7 +265,7 @@ int print_header(int option) {
 }
 
 
-inline ullong direction2value(char mode,struct inout_long stats) {
+static inline ullong direction2value(char mode,struct inout_long stats) {
     switch (mode) {
         case 0:
             return stats.in;
@@ -275,7 +278,7 @@ inline ullong direction2value(char mode,struct inout_long stats) {
 }
 
 #if EXTENDED_STATS
-inline double direction_max2value(char mode,struct inouttotal_double stats,int items) {
+static inline double direction_max2value(char mode,struct inouttotal_double stats,int items) {
     switch (mode) {
         case 0:
             return (double)(stats.in/items);
@@ -288,7 +291,7 @@ inline double direction_max2value(char mode,struct inouttotal_double stats,int i
 }
 #endif
 
-inline char *dyn_byte_value2str(double value,char *str,int buf_size) {
+static inline char *dyn_byte_value2str(double value,char *str,int buf_size) {
     if (dynamic) {
         if (value<1024)
             snprintf(str,buf_size,"%15.2f  ",value);
@@ -306,7 +309,7 @@ inline char *dyn_byte_value2str(double value,char *str,int buf_size) {
     return str;
 }
 
-inline char *dyn_bit_value2str(double value,char *str,int buf_size) {
+static inline char *dyn_bit_value2str(double value,char *str,int buf_size) {
     if (dynamic) {
         if (value<1000)
             snprintf(str,buf_size,"%15.2f  ",value);
@@ -418,6 +421,7 @@ char *values2str(char mode,t_iface_speed_stats stats,t_iface_stats full_stats,fl
 /* do the actual output */
 void print_values(unsigned int y,unsigned int x,const char *if_name,t_iface_speed_stats stats,float multiplier,t_iface_stats full_stats) {
    char buffer[50];
+   struct timeval now;
 #if CSV || HTML
 	FILE *tmp_out_file;
 #endif
@@ -540,7 +544,8 @@ void print_values(unsigned int y,unsigned int x,const char *if_name,t_iface_spee
 #ifdef CSV
         case CSV_OUT:
 				tmp_out_file=out_file==NULL ? stdout : out_file;
-            fprintf(tmp_out_file,"%i%c%s%c",(int)time(NULL),csv_char,if_name,csv_char);
+            gettimeofday(&now, NULL);
+            fprintf(tmp_out_file,"%1.6f%c%s%c",(((double)now.tv_sec * 1000000.0) + (double)now.tv_usec) / 1000000.0,csv_char,if_name,csv_char);
 				if (output_type == RATE_OUT || output_type == SUM_OUT) {
 					if (output_type == RATE_OUT) {
 						stats_csv = &stats;
@@ -552,6 +557,7 @@ void print_values(unsigned int y,unsigned int x,const char *if_name,t_iface_spee
    	            /* show packets/s and errors/s */
       	         fprintf(tmp_out_file,"%.2f%c%.2f%c%.2f%c%llu%c%llu",(double)stats_csv->packets.out*multiplier,csv_char,(double)stats_csv->packets.in*multiplier,csv_char,(double)(stats_csv->packets.out+stats_csv->packets.in)*multiplier,csv_char,stats_csv->packets.in,csv_char,stats_csv->packets.out);
          	      fprintf(tmp_out_file,"%c%.2f%c%.2f%c%llu%c%llu\n",csv_char,stats_csv->errors.out*multiplier,csv_char,stats_csv->errors.in*multiplier,csv_char,stats_csv->errors.in,csv_char,stats_csv->errors.out);
+					fflush(tmp_out_file);	
 
 					} else {
 						stats_csv = &full_stats.sum;
@@ -563,6 +569,7 @@ void print_values(unsigned int y,unsigned int x,const char *if_name,t_iface_spee
 						/* show packets and errors */
 						fprintf(tmp_out_file,"%llu%c%llu%c%llu",stats_csv->packets.out,csv_char,stats_csv->packets.in,csv_char,(stats_csv->packets.out+stats_csv->packets.in));
 						fprintf(tmp_out_file,"%c%llu%c%llu\n",csv_char,stats_csv->errors.out,csv_char,stats_csv->errors.in);
+					fflush(tmp_out_file);	
 						}
 				} else { /* MAX_OUT or AVG_OUT */
 					if (output_type == MAX_OUT)
