@@ -17,7 +17,7 @@
  *                                                                            *
  *  You should have received a copy of the GNU General Public License         *
  *  along with this program; if not, write to the Free Software               *
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA *
  *                                                                            *
  *****************************************************************************/
 
@@ -26,19 +26,19 @@
 
 short show_iface(char *instr, char *searchstr,char iface_is_up);
 #if HAVE_GETTIMEOFDAY
-inline long tvdiff(struct timeval newer, struct timeval older);
+static inline long tvdiff(struct timeval newer, struct timeval older);
 float get_time_delay(int iface_num);
 #endif
-inline ullong calc_new_values(ullong new, ullong old);
+static inline ullong calc_new_values(ullong new, ullong old);
 t_iface_speed_stats convert2calced_values(t_iface_speed_stats new, t_iface_speed_stats old);
 t_iface_speed_stats convert2calced_disk_values(t_iface_speed_stats new, t_iface_speed_stats old);
 #if EXTENDED_STATS
-inline void sub_avg_values(struct inouttotal_double *values,struct inouttotal_double data);
-inline void add_avg_values(struct inouttotal_double *values,struct inouttotal_double data);
-inline void save_avg_values(struct inouttotal_double *values,struct inouttotal_double *data,struct inout_long calced_stats,float multiplier);
+static inline void sub_avg_values(struct inouttotal_double *values,struct inouttotal_double data);
+static inline void add_avg_values(struct inouttotal_double *values,struct inouttotal_double data);
+static inline void save_avg_values(struct inouttotal_double *values,struct inouttotal_double *data,struct inout_long calced_stats,float multiplier);
 void save_avg(struct t_avg *avg,struct iface_speed_stats calced_stats,float multiplier);
-inline void save_sum(struct inout_long *stats,struct inout_long new_stats_values);
-inline void save_max(struct inouttotal_double *stats,struct inout_long calced_stats,float multiplier);
+static inline void save_sum(struct inout_long *stats,struct inout_long new_stats_values);
+static inline void save_max(struct inouttotal_double *stats,struct inout_long calced_stats,float multiplier);
 #endif
 
 /* returns the whether to show the iface or not
@@ -74,7 +74,7 @@ short show_iface(char *instr, char *searchstr,char iface_is_up) {
 
 #if HAVE_GETTIMEOFDAY
 /* Returns: the time difference in milliseconds. */
-inline long tvdiff(struct timeval newer, struct timeval older) {
+static inline long tvdiff(struct timeval newer, struct timeval older) {
   return labs((newer.tv_sec-older.tv_sec)*1000+
     (newer.tv_usec-older.tv_usec)/1000);
 }
@@ -82,9 +82,12 @@ inline long tvdiff(struct timeval newer, struct timeval older) {
 /* returns the milliseconds since old stat */
 float get_time_delay(int iface_num) {
     struct timeval now;
-    float ret;
+    float ret = 0.0f;
     gettimeofday(&now,NULL);
-    ret=(float)1000/tvdiff(now,if_stats[iface_num].time);
+	long diff = tvdiff(now,if_stats[iface_num].time);
+	if (diff > 0) {
+	    ret=(float)1000/diff;
+	}
     if_stats[iface_num].time.tv_sec=now.tv_sec;
     if_stats[iface_num].time.tv_usec=now.tv_usec;    
     return ret;
@@ -92,7 +95,7 @@ float get_time_delay(int iface_num) {
 #endif
 
 /* basically new-old, but handles "overflow" of source aswell */
-inline ullong calc_new_values(ullong new, ullong old) {
+static inline ullong calc_new_values(ullong new, ullong old) {
     /* FIXME: WRAP_AROUND _might_ be wrong for libstatgrab, where the type is always long long */
     return (new>=old) ? (ullong)(new-old) : (ullong)((
 #ifdef HAVE_LIBKSTAT
@@ -133,13 +136,13 @@ t_iface_speed_stats convert2calced_disk_values(t_iface_speed_stats new, t_iface_
 
 #if EXTENDED_STATS
 /* sub old values from cached for avg stats */
-inline void sub_avg_values(struct inouttotal_double *values,struct inouttotal_double data) {
+static inline void sub_avg_values(struct inouttotal_double *values,struct inouttotal_double data) {
     values->in-=data.in;
     values->out-=data.out;
     values->total-=data.total;
 }
 
-inline void add_avg_values(struct inouttotal_double *values,struct inouttotal_double data) {
+static inline void add_avg_values(struct inouttotal_double *values,struct inouttotal_double data) {
     values->in+=data.in;
     values->out+=data.out;
     values->total+=data.total;
@@ -148,7 +151,7 @@ inline void add_avg_values(struct inouttotal_double *values,struct inouttotal_do
 
 /* put new-old bytes in inout_long struct into a inouttotal_double struct 
  * and add values to cached .value struct */
-inline void save_avg_values(struct inouttotal_double *values,struct inouttotal_double *data,struct inout_long calced_stats,float multiplier) {
+static inline void save_avg_values(struct inouttotal_double *values,struct inouttotal_double *data,struct inout_long calced_stats,float multiplier) {
     data->in=calced_stats.in*multiplier;
     data->out=calced_stats.out*multiplier;
     data->total=(calced_stats.in+calced_stats.out)*multiplier;
@@ -198,13 +201,13 @@ void save_avg(struct t_avg *avg,struct iface_speed_stats calced_stats,float mult
 }
 
 /* add current in and out bytes to totals struct */
-inline void save_sum(struct inout_long *stats,struct inout_long new_stats_values) {
+static inline void save_sum(struct inout_long *stats,struct inout_long new_stats_values) {
     stats->in+=new_stats_values.in;
     stats->out+=new_stats_values.out;
 }
 
 /* lookup old max values and save new if higher */
-inline void save_max(struct inouttotal_double *stats,struct inout_long calced_stats,float multiplier) {
+static inline void save_max(struct inouttotal_double *stats,struct inout_long calced_stats,float multiplier) {
     if (multiplier*calced_stats.in > stats->in)
         stats->in=multiplier*calced_stats.in;
     if (multiplier*calced_stats.out>stats->out)
@@ -322,9 +325,12 @@ void finish_iface_stats (char verbose, t_iface_speed_stats stats, int hidden_if,
     t_iface_speed_stats calced_stats;
 #if HAVE_GETTIMEOFDAY
     struct timeval now;
-    float multiplier;
+    float multiplier=0.0f;
     gettimeofday(&now,NULL);
-    multiplier=(float)1000/tvdiff(now,if_stats_total.time);
+	long diff = tvdiff(now,if_stats_total.time);
+	if (diff > 0) {
+	    multiplier=(float)1000/tvdiff(now,if_stats_total.time);
+	}
     if_stats_total.time.tv_sec=now.tv_sec;
     if_stats_total.time.tv_usec=now.tv_usec;
 #else
